cdm_reference object from a sparklyr connection.Create a cdm_reference object from a sparklyr connection.
cdmFromSpark(
con,
cdmSchema,
writeSchema,
cohortTables = NULL,
cdmVersion = NULL,
cdmName = NULL,
achillesSchema = NULL,
.softValidation = FALSE,
writePrefix = NULL,
cdmPrefix = NULL
)A cdm reference object
A spark connection created with: sparklyr::spark_connect().
Schema where omop standard tables are located. Schema is defined with a named character list/vector; allowed names are: 'catalog', 'schema' and 'prefix'.
Schema where with writing permissions. Schema is defined with a named character list/vector; allowed names are: 'catalog', 'schema' and 'prefix'.
Names of cohort tables to be read from writeSchema.
The version of the cdm (either "5.3" or "5.4"). If NULL
cdm_source$cdm_version will be used instead.
The name of the cdm object, if NULL
cdm_source$cdm_source_name will be used instead.
Schema where achilled tables are located. Schema is defined with a named character list/vector; allowed names are: 'catalog', 'schema' and 'prefix'.
Whether to use soft validation, this is not recommended as analysis pipelines assume the cdm fullfill the validation criteria.
A prefix that will be added to all tables created in the write_schema. This can be used to create namespace in your database write_schema for your tables.
A prefix used with the OMOP CDM tables.